# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['LogsInputArgs', 'LogsInput']

@pulumi.input_type
class LogsInputArgs:
    def __init__(__self__, *,
                 configuration: pulumi.Input['LogsInputConfigurationArgs'],
                 description: pulumi.Input[builtins.str],
                 engine_id: pulumi.Input[builtins.str],
                 service_name: pulumi.Input[builtins.str],
                 stream_id: pulumi.Input[builtins.str],
                 title: pulumi.Input[builtins.str],
                 allowed_networks: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 autoscale: Optional[pulumi.Input[builtins.bool]] = None,
                 exposed_port: Optional[pulumi.Input[builtins.str]] = None,
                 max_scale_instance: Optional[pulumi.Input[builtins.int]] = None,
                 min_scale_instance: Optional[pulumi.Input[builtins.int]] = None,
                 nb_instance: Optional[pulumi.Input[builtins.int]] = None):
        """
        The set of arguments for constructing a LogsInput resource.
        :param pulumi.Input['LogsInputConfigurationArgs'] configuration: Input configuration
        :param pulumi.Input[builtins.str] description: Input description
        :param pulumi.Input[builtins.str] engine_id: Input engine ID
        :param pulumi.Input[builtins.str] service_name: service name
        :param pulumi.Input[builtins.str] stream_id: Associated Graylog stream
        :param pulumi.Input[builtins.str] title: Input title
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] allowed_networks: List of IP blocks
        :param pulumi.Input[builtins.bool] autoscale: Whether the workload is auto-scaled (mutually exclusive with parameter `nb_instance`)
        :param pulumi.Input[builtins.str] exposed_port: Port
        :param pulumi.Input[builtins.int] max_scale_instance: Maximum number of instances in auto-scaled mode
        :param pulumi.Input[builtins.int] min_scale_instance: Minimum number of instances in auto-scaled mode
        :param pulumi.Input[builtins.int] nb_instance: Number of instance running (input, mutually exclusive with parameter `autoscale`)
        """
        pulumi.set(__self__, "configuration", configuration)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "engine_id", engine_id)
        pulumi.set(__self__, "service_name", service_name)
        pulumi.set(__self__, "stream_id", stream_id)
        pulumi.set(__self__, "title", title)
        if allowed_networks is not None:
            pulumi.set(__self__, "allowed_networks", allowed_networks)
        if autoscale is not None:
            pulumi.set(__self__, "autoscale", autoscale)
        if exposed_port is not None:
            pulumi.set(__self__, "exposed_port", exposed_port)
        if max_scale_instance is not None:
            pulumi.set(__self__, "max_scale_instance", max_scale_instance)
        if min_scale_instance is not None:
            pulumi.set(__self__, "min_scale_instance", min_scale_instance)
        if nb_instance is not None:
            pulumi.set(__self__, "nb_instance", nb_instance)

    @property
    @pulumi.getter
    def configuration(self) -> pulumi.Input['LogsInputConfigurationArgs']:
        """
        Input configuration
        """
        return pulumi.get(self, "configuration")

    @configuration.setter
    def configuration(self, value: pulumi.Input['LogsInputConfigurationArgs']):
        pulumi.set(self, "configuration", value)

    @property
    @pulumi.getter
    def description(self) -> pulumi.Input[builtins.str]:
        """
        Input description
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="engineId")
    def engine_id(self) -> pulumi.Input[builtins.str]:
        """
        Input engine ID
        """
        return pulumi.get(self, "engine_id")

    @engine_id.setter
    def engine_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "engine_id", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Input[builtins.str]:
        """
        service name
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter(name="streamId")
    def stream_id(self) -> pulumi.Input[builtins.str]:
        """
        Associated Graylog stream
        """
        return pulumi.get(self, "stream_id")

    @stream_id.setter
    def stream_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "stream_id", value)

    @property
    @pulumi.getter
    def title(self) -> pulumi.Input[builtins.str]:
        """
        Input title
        """
        return pulumi.get(self, "title")

    @title.setter
    def title(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "title", value)

    @property
    @pulumi.getter(name="allowedNetworks")
    def allowed_networks(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        List of IP blocks
        """
        return pulumi.get(self, "allowed_networks")

    @allowed_networks.setter
    def allowed_networks(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "allowed_networks", value)

    @property
    @pulumi.getter
    def autoscale(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether the workload is auto-scaled (mutually exclusive with parameter `nb_instance`)
        """
        return pulumi.get(self, "autoscale")

    @autoscale.setter
    def autoscale(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "autoscale", value)

    @property
    @pulumi.getter(name="exposedPort")
    def exposed_port(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Port
        """
        return pulumi.get(self, "exposed_port")

    @exposed_port.setter
    def exposed_port(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "exposed_port", value)

    @property
    @pulumi.getter(name="maxScaleInstance")
    def max_scale_instance(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Maximum number of instances in auto-scaled mode
        """
        return pulumi.get(self, "max_scale_instance")

    @max_scale_instance.setter
    def max_scale_instance(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "max_scale_instance", value)

    @property
    @pulumi.getter(name="minScaleInstance")
    def min_scale_instance(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Minimum number of instances in auto-scaled mode
        """
        return pulumi.get(self, "min_scale_instance")

    @min_scale_instance.setter
    def min_scale_instance(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "min_scale_instance", value)

    @property
    @pulumi.getter(name="nbInstance")
    def nb_instance(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Number of instance running (input, mutually exclusive with parameter `autoscale`)
        """
        return pulumi.get(self, "nb_instance")

    @nb_instance.setter
    def nb_instance(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "nb_instance", value)


@pulumi.input_type
class _LogsInputState:
    def __init__(__self__, *,
                 allowed_networks: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 autoscale: Optional[pulumi.Input[builtins.bool]] = None,
                 configuration: Optional[pulumi.Input['LogsInputConfigurationArgs']] = None,
                 created_at: Optional[pulumi.Input[builtins.str]] = None,
                 current_nb_instance: Optional[pulumi.Input[builtins.int]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 engine_id: Optional[pulumi.Input[builtins.str]] = None,
                 exposed_port: Optional[pulumi.Input[builtins.str]] = None,
                 hostname: Optional[pulumi.Input[builtins.str]] = None,
                 input_id: Optional[pulumi.Input[builtins.str]] = None,
                 is_restart_required: Optional[pulumi.Input[builtins.bool]] = None,
                 max_scale_instance: Optional[pulumi.Input[builtins.int]] = None,
                 min_scale_instance: Optional[pulumi.Input[builtins.int]] = None,
                 nb_instance: Optional[pulumi.Input[builtins.int]] = None,
                 public_address: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 ssl_certificate: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 stream_id: Optional[pulumi.Input[builtins.str]] = None,
                 title: Optional[pulumi.Input[builtins.str]] = None,
                 updated_at: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering LogsInput resources.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] allowed_networks: List of IP blocks
        :param pulumi.Input[builtins.bool] autoscale: Whether the workload is auto-scaled (mutually exclusive with parameter `nb_instance`)
        :param pulumi.Input['LogsInputConfigurationArgs'] configuration: Input configuration
        :param pulumi.Input[builtins.str] created_at: Input creation
        :param pulumi.Input[builtins.int] current_nb_instance: Number of instance running (returned by the API)
        :param pulumi.Input[builtins.str] description: Input description
        :param pulumi.Input[builtins.str] engine_id: Input engine ID
        :param pulumi.Input[builtins.str] exposed_port: Port
        :param pulumi.Input[builtins.str] hostname: Hostname
        :param pulumi.Input[builtins.str] input_id: Input ID
        :param pulumi.Input[builtins.bool] is_restart_required: Indicate if input need to be restarted
        :param pulumi.Input[builtins.int] max_scale_instance: Maximum number of instances in auto-scaled mode
        :param pulumi.Input[builtins.int] min_scale_instance: Minimum number of instances in auto-scaled mode
        :param pulumi.Input[builtins.int] nb_instance: Number of instance running (input, mutually exclusive with parameter `autoscale`)
        :param pulumi.Input[builtins.str] public_address: Input IP address
        :param pulumi.Input[builtins.str] service_name: service name
        :param pulumi.Input[builtins.str] ssl_certificate: Input SSL certificate
        :param pulumi.Input[builtins.str] status: init: configuration required, pending: ready to start, running: available
        :param pulumi.Input[builtins.str] stream_id: Associated Graylog stream
        :param pulumi.Input[builtins.str] title: Input title
        :param pulumi.Input[builtins.str] updated_at: Input last update
        """
        if allowed_networks is not None:
            pulumi.set(__self__, "allowed_networks", allowed_networks)
        if autoscale is not None:
            pulumi.set(__self__, "autoscale", autoscale)
        if configuration is not None:
            pulumi.set(__self__, "configuration", configuration)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if current_nb_instance is not None:
            pulumi.set(__self__, "current_nb_instance", current_nb_instance)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if engine_id is not None:
            pulumi.set(__self__, "engine_id", engine_id)
        if exposed_port is not None:
            pulumi.set(__self__, "exposed_port", exposed_port)
        if hostname is not None:
            pulumi.set(__self__, "hostname", hostname)
        if input_id is not None:
            pulumi.set(__self__, "input_id", input_id)
        if is_restart_required is not None:
            pulumi.set(__self__, "is_restart_required", is_restart_required)
        if max_scale_instance is not None:
            pulumi.set(__self__, "max_scale_instance", max_scale_instance)
        if min_scale_instance is not None:
            pulumi.set(__self__, "min_scale_instance", min_scale_instance)
        if nb_instance is not None:
            pulumi.set(__self__, "nb_instance", nb_instance)
        if public_address is not None:
            pulumi.set(__self__, "public_address", public_address)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)
        if ssl_certificate is not None:
            pulumi.set(__self__, "ssl_certificate", ssl_certificate)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if stream_id is not None:
            pulumi.set(__self__, "stream_id", stream_id)
        if title is not None:
            pulumi.set(__self__, "title", title)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)

    @property
    @pulumi.getter(name="allowedNetworks")
    def allowed_networks(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        List of IP blocks
        """
        return pulumi.get(self, "allowed_networks")

    @allowed_networks.setter
    def allowed_networks(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "allowed_networks", value)

    @property
    @pulumi.getter
    def autoscale(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether the workload is auto-scaled (mutually exclusive with parameter `nb_instance`)
        """
        return pulumi.get(self, "autoscale")

    @autoscale.setter
    def autoscale(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "autoscale", value)

    @property
    @pulumi.getter
    def configuration(self) -> Optional[pulumi.Input['LogsInputConfigurationArgs']]:
        """
        Input configuration
        """
        return pulumi.get(self, "configuration")

    @configuration.setter
    def configuration(self, value: Optional[pulumi.Input['LogsInputConfigurationArgs']]):
        pulumi.set(self, "configuration", value)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Input creation
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_at", value)

    @property
    @pulumi.getter(name="currentNbInstance")
    def current_nb_instance(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Number of instance running (returned by the API)
        """
        return pulumi.get(self, "current_nb_instance")

    @current_nb_instance.setter
    def current_nb_instance(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "current_nb_instance", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Input description
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="engineId")
    def engine_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Input engine ID
        """
        return pulumi.get(self, "engine_id")

    @engine_id.setter
    def engine_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "engine_id", value)

    @property
    @pulumi.getter(name="exposedPort")
    def exposed_port(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Port
        """
        return pulumi.get(self, "exposed_port")

    @exposed_port.setter
    def exposed_port(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "exposed_port", value)

    @property
    @pulumi.getter
    def hostname(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Hostname
        """
        return pulumi.get(self, "hostname")

    @hostname.setter
    def hostname(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "hostname", value)

    @property
    @pulumi.getter(name="inputId")
    def input_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Input ID
        """
        return pulumi.get(self, "input_id")

    @input_id.setter
    def input_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "input_id", value)

    @property
    @pulumi.getter(name="isRestartRequired")
    def is_restart_required(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Indicate if input need to be restarted
        """
        return pulumi.get(self, "is_restart_required")

    @is_restart_required.setter
    def is_restart_required(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "is_restart_required", value)

    @property
    @pulumi.getter(name="maxScaleInstance")
    def max_scale_instance(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Maximum number of instances in auto-scaled mode
        """
        return pulumi.get(self, "max_scale_instance")

    @max_scale_instance.setter
    def max_scale_instance(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "max_scale_instance", value)

    @property
    @pulumi.getter(name="minScaleInstance")
    def min_scale_instance(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Minimum number of instances in auto-scaled mode
        """
        return pulumi.get(self, "min_scale_instance")

    @min_scale_instance.setter
    def min_scale_instance(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "min_scale_instance", value)

    @property
    @pulumi.getter(name="nbInstance")
    def nb_instance(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Number of instance running (input, mutually exclusive with parameter `autoscale`)
        """
        return pulumi.get(self, "nb_instance")

    @nb_instance.setter
    def nb_instance(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "nb_instance", value)

    @property
    @pulumi.getter(name="publicAddress")
    def public_address(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Input IP address
        """
        return pulumi.get(self, "public_address")

    @public_address.setter
    def public_address(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "public_address", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        service name
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter(name="sslCertificate")
    def ssl_certificate(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Input SSL certificate
        """
        return pulumi.get(self, "ssl_certificate")

    @ssl_certificate.setter
    def ssl_certificate(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ssl_certificate", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        init: configuration required, pending: ready to start, running: available
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="streamId")
    def stream_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Associated Graylog stream
        """
        return pulumi.get(self, "stream_id")

    @stream_id.setter
    def stream_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "stream_id", value)

    @property
    @pulumi.getter
    def title(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Input title
        """
        return pulumi.get(self, "title")

    @title.setter
    def title(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "title", value)

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Input last update
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "updated_at", value)


class LogsInput(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 allowed_networks: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 autoscale: Optional[pulumi.Input[builtins.bool]] = None,
                 configuration: Optional[pulumi.Input[Union['LogsInputConfigurationArgs', 'LogsInputConfigurationArgsDict']]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 engine_id: Optional[pulumi.Input[builtins.str]] = None,
                 exposed_port: Optional[pulumi.Input[builtins.str]] = None,
                 max_scale_instance: Optional[pulumi.Input[builtins.int]] = None,
                 min_scale_instance: Optional[pulumi.Input[builtins.int]] = None,
                 nb_instance: Optional[pulumi.Input[builtins.int]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 stream_id: Optional[pulumi.Input[builtins.str]] = None,
                 title: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Creates a dbaas logs input.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        logstash = ovh.Dbaas.get_logs_input_engine(name="logstash",
            version="7.x")
        stream = ovh.dbaas.LogsOutputGraylogStream("stream",
            service_name="....",
            title="my stream",
            description="my graylog stream")
        input = ovh.dbaas.LogsInput("input",
            service_name=stream.service_name,
            description=stream.description,
            title=stream.title,
            engine_id=logstash.id,
            stream_id=stream.id,
            allowed_networks=["10.0.0.0/16"],
            exposed_port="6154",
            nb_instance=2,
            configuration={
                "logstash": {
                    "input_section": \"\"\"  beats {
            port => 6514
            ssl => true
            ssl_certificate => "/etc/ssl/private/server.crt"
            ssl_key => "/etc/ssl/private/server.key"
          }
        \"\"\",
                },
            })
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] allowed_networks: List of IP blocks
        :param pulumi.Input[builtins.bool] autoscale: Whether the workload is auto-scaled (mutually exclusive with parameter `nb_instance`)
        :param pulumi.Input[Union['LogsInputConfigurationArgs', 'LogsInputConfigurationArgsDict']] configuration: Input configuration
        :param pulumi.Input[builtins.str] description: Input description
        :param pulumi.Input[builtins.str] engine_id: Input engine ID
        :param pulumi.Input[builtins.str] exposed_port: Port
        :param pulumi.Input[builtins.int] max_scale_instance: Maximum number of instances in auto-scaled mode
        :param pulumi.Input[builtins.int] min_scale_instance: Minimum number of instances in auto-scaled mode
        :param pulumi.Input[builtins.int] nb_instance: Number of instance running (input, mutually exclusive with parameter `autoscale`)
        :param pulumi.Input[builtins.str] service_name: service name
        :param pulumi.Input[builtins.str] stream_id: Associated Graylog stream
        :param pulumi.Input[builtins.str] title: Input title
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: LogsInputArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates a dbaas logs input.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        logstash = ovh.Dbaas.get_logs_input_engine(name="logstash",
            version="7.x")
        stream = ovh.dbaas.LogsOutputGraylogStream("stream",
            service_name="....",
            title="my stream",
            description="my graylog stream")
        input = ovh.dbaas.LogsInput("input",
            service_name=stream.service_name,
            description=stream.description,
            title=stream.title,
            engine_id=logstash.id,
            stream_id=stream.id,
            allowed_networks=["10.0.0.0/16"],
            exposed_port="6154",
            nb_instance=2,
            configuration={
                "logstash": {
                    "input_section": \"\"\"  beats {
            port => 6514
            ssl => true
            ssl_certificate => "/etc/ssl/private/server.crt"
            ssl_key => "/etc/ssl/private/server.key"
          }
        \"\"\",
                },
            })
        ```

        :param str resource_name: The name of the resource.
        :param LogsInputArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(LogsInputArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 allowed_networks: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 autoscale: Optional[pulumi.Input[builtins.bool]] = None,
                 configuration: Optional[pulumi.Input[Union['LogsInputConfigurationArgs', 'LogsInputConfigurationArgsDict']]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 engine_id: Optional[pulumi.Input[builtins.str]] = None,
                 exposed_port: Optional[pulumi.Input[builtins.str]] = None,
                 max_scale_instance: Optional[pulumi.Input[builtins.int]] = None,
                 min_scale_instance: Optional[pulumi.Input[builtins.int]] = None,
                 nb_instance: Optional[pulumi.Input[builtins.int]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 stream_id: Optional[pulumi.Input[builtins.str]] = None,
                 title: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = LogsInputArgs.__new__(LogsInputArgs)

            __props__.__dict__["allowed_networks"] = allowed_networks
            __props__.__dict__["autoscale"] = autoscale
            if configuration is None and not opts.urn:
                raise TypeError("Missing required property 'configuration'")
            __props__.__dict__["configuration"] = configuration
            if description is None and not opts.urn:
                raise TypeError("Missing required property 'description'")
            __props__.__dict__["description"] = description
            if engine_id is None and not opts.urn:
                raise TypeError("Missing required property 'engine_id'")
            __props__.__dict__["engine_id"] = engine_id
            __props__.__dict__["exposed_port"] = exposed_port
            __props__.__dict__["max_scale_instance"] = max_scale_instance
            __props__.__dict__["min_scale_instance"] = min_scale_instance
            __props__.__dict__["nb_instance"] = nb_instance
            if service_name is None and not opts.urn:
                raise TypeError("Missing required property 'service_name'")
            __props__.__dict__["service_name"] = service_name
            if stream_id is None and not opts.urn:
                raise TypeError("Missing required property 'stream_id'")
            __props__.__dict__["stream_id"] = stream_id
            if title is None and not opts.urn:
                raise TypeError("Missing required property 'title'")
            __props__.__dict__["title"] = title
            __props__.__dict__["created_at"] = None
            __props__.__dict__["current_nb_instance"] = None
            __props__.__dict__["hostname"] = None
            __props__.__dict__["input_id"] = None
            __props__.__dict__["is_restart_required"] = None
            __props__.__dict__["public_address"] = None
            __props__.__dict__["ssl_certificate"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["updated_at"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["sslCertificate"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(LogsInput, __self__).__init__(
            'ovh:Dbaas/logsInput:LogsInput',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            allowed_networks: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            autoscale: Optional[pulumi.Input[builtins.bool]] = None,
            configuration: Optional[pulumi.Input[Union['LogsInputConfigurationArgs', 'LogsInputConfigurationArgsDict']]] = None,
            created_at: Optional[pulumi.Input[builtins.str]] = None,
            current_nb_instance: Optional[pulumi.Input[builtins.int]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            engine_id: Optional[pulumi.Input[builtins.str]] = None,
            exposed_port: Optional[pulumi.Input[builtins.str]] = None,
            hostname: Optional[pulumi.Input[builtins.str]] = None,
            input_id: Optional[pulumi.Input[builtins.str]] = None,
            is_restart_required: Optional[pulumi.Input[builtins.bool]] = None,
            max_scale_instance: Optional[pulumi.Input[builtins.int]] = None,
            min_scale_instance: Optional[pulumi.Input[builtins.int]] = None,
            nb_instance: Optional[pulumi.Input[builtins.int]] = None,
            public_address: Optional[pulumi.Input[builtins.str]] = None,
            service_name: Optional[pulumi.Input[builtins.str]] = None,
            ssl_certificate: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            stream_id: Optional[pulumi.Input[builtins.str]] = None,
            title: Optional[pulumi.Input[builtins.str]] = None,
            updated_at: Optional[pulumi.Input[builtins.str]] = None) -> 'LogsInput':
        """
        Get an existing LogsInput resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] allowed_networks: List of IP blocks
        :param pulumi.Input[builtins.bool] autoscale: Whether the workload is auto-scaled (mutually exclusive with parameter `nb_instance`)
        :param pulumi.Input[Union['LogsInputConfigurationArgs', 'LogsInputConfigurationArgsDict']] configuration: Input configuration
        :param pulumi.Input[builtins.str] created_at: Input creation
        :param pulumi.Input[builtins.int] current_nb_instance: Number of instance running (returned by the API)
        :param pulumi.Input[builtins.str] description: Input description
        :param pulumi.Input[builtins.str] engine_id: Input engine ID
        :param pulumi.Input[builtins.str] exposed_port: Port
        :param pulumi.Input[builtins.str] hostname: Hostname
        :param pulumi.Input[builtins.str] input_id: Input ID
        :param pulumi.Input[builtins.bool] is_restart_required: Indicate if input need to be restarted
        :param pulumi.Input[builtins.int] max_scale_instance: Maximum number of instances in auto-scaled mode
        :param pulumi.Input[builtins.int] min_scale_instance: Minimum number of instances in auto-scaled mode
        :param pulumi.Input[builtins.int] nb_instance: Number of instance running (input, mutually exclusive with parameter `autoscale`)
        :param pulumi.Input[builtins.str] public_address: Input IP address
        :param pulumi.Input[builtins.str] service_name: service name
        :param pulumi.Input[builtins.str] ssl_certificate: Input SSL certificate
        :param pulumi.Input[builtins.str] status: init: configuration required, pending: ready to start, running: available
        :param pulumi.Input[builtins.str] stream_id: Associated Graylog stream
        :param pulumi.Input[builtins.str] title: Input title
        :param pulumi.Input[builtins.str] updated_at: Input last update
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _LogsInputState.__new__(_LogsInputState)

        __props__.__dict__["allowed_networks"] = allowed_networks
        __props__.__dict__["autoscale"] = autoscale
        __props__.__dict__["configuration"] = configuration
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["current_nb_instance"] = current_nb_instance
        __props__.__dict__["description"] = description
        __props__.__dict__["engine_id"] = engine_id
        __props__.__dict__["exposed_port"] = exposed_port
        __props__.__dict__["hostname"] = hostname
        __props__.__dict__["input_id"] = input_id
        __props__.__dict__["is_restart_required"] = is_restart_required
        __props__.__dict__["max_scale_instance"] = max_scale_instance
        __props__.__dict__["min_scale_instance"] = min_scale_instance
        __props__.__dict__["nb_instance"] = nb_instance
        __props__.__dict__["public_address"] = public_address
        __props__.__dict__["service_name"] = service_name
        __props__.__dict__["ssl_certificate"] = ssl_certificate
        __props__.__dict__["status"] = status
        __props__.__dict__["stream_id"] = stream_id
        __props__.__dict__["title"] = title
        __props__.__dict__["updated_at"] = updated_at
        return LogsInput(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="allowedNetworks")
    def allowed_networks(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        List of IP blocks
        """
        return pulumi.get(self, "allowed_networks")

    @property
    @pulumi.getter
    def autoscale(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Whether the workload is auto-scaled (mutually exclusive with parameter `nb_instance`)
        """
        return pulumi.get(self, "autoscale")

    @property
    @pulumi.getter
    def configuration(self) -> pulumi.Output['outputs.LogsInputConfiguration']:
        """
        Input configuration
        """
        return pulumi.get(self, "configuration")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[builtins.str]:
        """
        Input creation
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter(name="currentNbInstance")
    def current_nb_instance(self) -> pulumi.Output[builtins.int]:
        """
        Number of instance running (returned by the API)
        """
        return pulumi.get(self, "current_nb_instance")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        Input description
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="engineId")
    def engine_id(self) -> pulumi.Output[builtins.str]:
        """
        Input engine ID
        """
        return pulumi.get(self, "engine_id")

    @property
    @pulumi.getter(name="exposedPort")
    def exposed_port(self) -> pulumi.Output[builtins.str]:
        """
        Port
        """
        return pulumi.get(self, "exposed_port")

    @property
    @pulumi.getter
    def hostname(self) -> pulumi.Output[builtins.str]:
        """
        Hostname
        """
        return pulumi.get(self, "hostname")

    @property
    @pulumi.getter(name="inputId")
    def input_id(self) -> pulumi.Output[builtins.str]:
        """
        Input ID
        """
        return pulumi.get(self, "input_id")

    @property
    @pulumi.getter(name="isRestartRequired")
    def is_restart_required(self) -> pulumi.Output[builtins.bool]:
        """
        Indicate if input need to be restarted
        """
        return pulumi.get(self, "is_restart_required")

    @property
    @pulumi.getter(name="maxScaleInstance")
    def max_scale_instance(self) -> pulumi.Output[Optional[builtins.int]]:
        """
        Maximum number of instances in auto-scaled mode
        """
        return pulumi.get(self, "max_scale_instance")

    @property
    @pulumi.getter(name="minScaleInstance")
    def min_scale_instance(self) -> pulumi.Output[Optional[builtins.int]]:
        """
        Minimum number of instances in auto-scaled mode
        """
        return pulumi.get(self, "min_scale_instance")

    @property
    @pulumi.getter(name="nbInstance")
    def nb_instance(self) -> pulumi.Output[Optional[builtins.int]]:
        """
        Number of instance running (input, mutually exclusive with parameter `autoscale`)
        """
        return pulumi.get(self, "nb_instance")

    @property
    @pulumi.getter(name="publicAddress")
    def public_address(self) -> pulumi.Output[builtins.str]:
        """
        Input IP address
        """
        return pulumi.get(self, "public_address")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Output[builtins.str]:
        """
        service name
        """
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter(name="sslCertificate")
    def ssl_certificate(self) -> pulumi.Output[builtins.str]:
        """
        Input SSL certificate
        """
        return pulumi.get(self, "ssl_certificate")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        init: configuration required, pending: ready to start, running: available
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="streamId")
    def stream_id(self) -> pulumi.Output[builtins.str]:
        """
        Associated Graylog stream
        """
        return pulumi.get(self, "stream_id")

    @property
    @pulumi.getter
    def title(self) -> pulumi.Output[builtins.str]:
        """
        Input title
        """
        return pulumi.get(self, "title")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[builtins.str]:
        """
        Input last update
        """
        return pulumi.get(self, "updated_at")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetPrivateDatabaseDbResult',
    'AwaitableGetPrivateDatabaseDbResult',
    'get_private_database_db',
    'get_private_database_db_output',
]

@pulumi.output_type
class GetPrivateDatabaseDbResult:
    """
    A collection of values returned by getPrivateDatabaseDb.
    """
    def __init__(__self__, backup_time=None, creation_date=None, database_name=None, id=None, quota_used=None, service_name=None, users=None):
        if backup_time and not isinstance(backup_time, str):
            raise TypeError("Expected argument 'backup_time' to be a str")
        pulumi.set(__self__, "backup_time", backup_time)
        if creation_date and not isinstance(creation_date, str):
            raise TypeError("Expected argument 'creation_date' to be a str")
        pulumi.set(__self__, "creation_date", creation_date)
        if database_name and not isinstance(database_name, str):
            raise TypeError("Expected argument 'database_name' to be a str")
        pulumi.set(__self__, "database_name", database_name)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if quota_used and not isinstance(quota_used, int):
            raise TypeError("Expected argument 'quota_used' to be a int")
        pulumi.set(__self__, "quota_used", quota_used)
        if service_name and not isinstance(service_name, str):
            raise TypeError("Expected argument 'service_name' to be a str")
        pulumi.set(__self__, "service_name", service_name)
        if users and not isinstance(users, list):
            raise TypeError("Expected argument 'users' to be a list")
        pulumi.set(__self__, "users", users)

    @property
    @pulumi.getter(name="backupTime")
    def backup_time(self) -> builtins.str:
        """
        Time of the next backup (every day)
        """
        return pulumi.get(self, "backup_time")

    @property
    @pulumi.getter(name="creationDate")
    def creation_date(self) -> builtins.str:
        """
        Creation date of the database
        """
        return pulumi.get(self, "creation_date")

    @property
    @pulumi.getter(name="databaseName")
    def database_name(self) -> builtins.str:
        return pulumi.get(self, "database_name")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="quotaUsed")
    def quota_used(self) -> builtins.int:
        """
        Space used by the database (in MB)
        """
        return pulumi.get(self, "quota_used")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> builtins.str:
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter
    def users(self) -> Sequence['outputs.GetPrivateDatabaseDbUserResult']:
        """
        Users granted to this database
        """
        return pulumi.get(self, "users")


class AwaitableGetPrivateDatabaseDbResult(GetPrivateDatabaseDbResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetPrivateDatabaseDbResult(
            backup_time=self.backup_time,
            creation_date=self.creation_date,
            database_name=self.database_name,
            id=self.id,
            quota_used=self.quota_used,
            service_name=self.service_name,
            users=self.users)


def get_private_database_db(database_name: Optional[builtins.str] = None,
                            service_name: Optional[builtins.str] = None,
                            opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetPrivateDatabaseDbResult:
    """
    Use this data source to retrieve information about an hosting privatedatabase.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    my_database = ovh.Hosting.get_private_database_db(service_name="XXXXXX",
        database_name="XXXXXX")
    ```


    :param builtins.str database_name: Database name
    :param builtins.str service_name: The internal name of your private database
    """
    __args__ = dict()
    __args__['databaseName'] = database_name
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:Hosting/getPrivateDatabaseDb:getPrivateDatabaseDb', __args__, opts=opts, typ=GetPrivateDatabaseDbResult).value

    return AwaitableGetPrivateDatabaseDbResult(
        backup_time=pulumi.get(__ret__, 'backup_time'),
        creation_date=pulumi.get(__ret__, 'creation_date'),
        database_name=pulumi.get(__ret__, 'database_name'),
        id=pulumi.get(__ret__, 'id'),
        quota_used=pulumi.get(__ret__, 'quota_used'),
        service_name=pulumi.get(__ret__, 'service_name'),
        users=pulumi.get(__ret__, 'users'))
def get_private_database_db_output(database_name: Optional[pulumi.Input[builtins.str]] = None,
                                   service_name: Optional[pulumi.Input[builtins.str]] = None,
                                   opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetPrivateDatabaseDbResult]:
    """
    Use this data source to retrieve information about an hosting privatedatabase.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    my_database = ovh.Hosting.get_private_database_db(service_name="XXXXXX",
        database_name="XXXXXX")
    ```


    :param builtins.str database_name: Database name
    :param builtins.str service_name: The internal name of your private database
    """
    __args__ = dict()
    __args__['databaseName'] = database_name
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:Hosting/getPrivateDatabaseDb:getPrivateDatabaseDb', __args__, opts=opts, typ=GetPrivateDatabaseDbResult)
    return __ret__.apply(lambda __response__: GetPrivateDatabaseDbResult(
        backup_time=pulumi.get(__response__, 'backup_time'),
        creation_date=pulumi.get(__response__, 'creation_date'),
        database_name=pulumi.get(__response__, 'database_name'),
        id=pulumi.get(__response__, 'id'),
        quota_used=pulumi.get(__response__, 'quota_used'),
        service_name=pulumi.get(__response__, 'service_name'),
        users=pulumi.get(__response__, 'users')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['KubeArgs', 'Kube']

@pulumi.input_type
class KubeArgs:
    def __init__(__self__, *,
                 region: pulumi.Input[builtins.str],
                 service_name: pulumi.Input[builtins.str],
                 customization_apiservers: Optional[pulumi.Input[Sequence[pulumi.Input['KubeCustomizationApiserverArgs']]]] = None,
                 customization_kube_proxy: Optional[pulumi.Input['KubeCustomizationKubeProxyArgs']] = None,
                 customizations: Optional[pulumi.Input[Sequence[pulumi.Input['KubeCustomizationArgs']]]] = None,
                 kube_proxy_mode: Optional[pulumi.Input[builtins.str]] = None,
                 load_balancers_subnet_id: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 nodes_subnet_id: Optional[pulumi.Input[builtins.str]] = None,
                 private_network_configuration: Optional[pulumi.Input['KubePrivateNetworkConfigurationArgs']] = None,
                 private_network_id: Optional[pulumi.Input[builtins.str]] = None,
                 update_policy: Optional[pulumi.Input[builtins.str]] = None,
                 version: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a Kube resource.
        :param pulumi.Input[builtins.str] region: a valid OVHcloud public cloud region ID in which the kubernetes cluster will be available. Ex.: "GRA1". Defaults to all public cloud regions. **Changing this value recreates the resource.**
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used. **Changing this value recreates the resource.**
        :param pulumi.Input[Sequence[pulumi.Input['KubeCustomizationApiserverArgs']]] customization_apiservers: Kubernetes API server customization
        :param pulumi.Input['KubeCustomizationKubeProxyArgs'] customization_kube_proxy: Kubernetes kube-proxy customization
        :param pulumi.Input[Sequence[pulumi.Input['KubeCustomizationArgs']]] customizations: **Deprecated** (Optional) Use `customization_apiserver` and `customization_kube_proxy` instead. Kubernetes cluster customization
        :param pulumi.Input[builtins.str] kube_proxy_mode: Selected mode for kube-proxy. **Changing this value recreates the resource, including ETCD user data.** Defaults to `iptables`.
        :param pulumi.Input[builtins.str] load_balancers_subnet_id: Subnet ID to use for Public Load Balancers, this subnet must belong to  `private_network_id`. Defaults to the same subnet as the nodes (see `nodes_subnet_id`). Requires `private_network_id` to be defined. See more network requirements in the [documentation](https://help.ovhcloud.com/csm/fr-public-cloud-kubernetes-expose-applications-using-load-balancer?id=kb_article_view&sysparm_article=KB0062873) for more information.
        :param pulumi.Input[builtins.str] name: The name of the kubernetes cluster.
        :param pulumi.Input[builtins.str] nodes_subnet_id: Subnet ID to use for nodes, this subnet must belong to `private_network_id`. Default uses the first subnet belonging to the private network with id `private_network_id`. This attribute requires `private_network_id` to be defined. **Cannot be updated, it can only be used at cluster creation or reset.**
        :param pulumi.Input['KubePrivateNetworkConfigurationArgs'] private_network_configuration: The private network configuration. If this is set then the 2 parameters below shall be defined.
        :param pulumi.Input[builtins.str] private_network_id: Private network ID to use. **Changing this value recreates the resource, including ETCD user data.** Defaults - not use private network.
               
               > **WARNING** Updating the private network ID resets the cluster so that all user data is deleted.
        :param pulumi.Input[builtins.str] update_policy: Cluster update policy. Choose between [ALWAYS_UPDATE, MINIMAL_DOWNTIME, NEVER_UPDATE].
        :param pulumi.Input[builtins.str] version: kubernetes version to use. Changing this value updates the resource. Defaults to the latest available.
        """
        pulumi.set(__self__, "region", region)
        pulumi.set(__self__, "service_name", service_name)
        if customization_apiservers is not None:
            pulumi.set(__self__, "customization_apiservers", customization_apiservers)
        if customization_kube_proxy is not None:
            pulumi.set(__self__, "customization_kube_proxy", customization_kube_proxy)
        if customizations is not None:
            warnings.warn("""Use customization_apiserver instead""", DeprecationWarning)
            pulumi.log.warn("""customizations is deprecated: Use customization_apiserver instead""")
        if customizations is not None:
            pulumi.set(__self__, "customizations", customizations)
        if kube_proxy_mode is not None:
            pulumi.set(__self__, "kube_proxy_mode", kube_proxy_mode)
        if load_balancers_subnet_id is not None:
            pulumi.set(__self__, "load_balancers_subnet_id", load_balancers_subnet_id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if nodes_subnet_id is not None:
            pulumi.set(__self__, "nodes_subnet_id", nodes_subnet_id)
        if private_network_configuration is not None:
            pulumi.set(__self__, "private_network_configuration", private_network_configuration)
        if private_network_id is not None:
            pulumi.set(__self__, "private_network_id", private_network_id)
        if update_policy is not None:
            pulumi.set(__self__, "update_policy", update_policy)
        if version is not None:
            pulumi.set(__self__, "version", version)

    @property
    @pulumi.getter
    def region(self) -> pulumi.Input[builtins.str]:
        """
        a valid OVHcloud public cloud region ID in which the kubernetes cluster will be available. Ex.: "GRA1". Defaults to all public cloud regions. **Changing this value recreates the resource.**
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "region", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Input[builtins.str]:
        """
        The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used. **Changing this value recreates the resource.**
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter(name="customizationApiservers")
    def customization_apiservers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['KubeCustomizationApiserverArgs']]]]:
        """
        Kubernetes API server customization
        """
        return pulumi.get(self, "customization_apiservers")

    @customization_apiservers.setter
    def customization_apiservers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['KubeCustomizationApiserverArgs']]]]):
        pulumi.set(self, "customization_apiservers", value)

    @property
    @pulumi.getter(name="customizationKubeProxy")
    def customization_kube_proxy(self) -> Optional[pulumi.Input['KubeCustomizationKubeProxyArgs']]:
        """
        Kubernetes kube-proxy customization
        """
        return pulumi.get(self, "customization_kube_proxy")

    @customization_kube_proxy.setter
    def customization_kube_proxy(self, value: Optional[pulumi.Input['KubeCustomizationKubeProxyArgs']]):
        pulumi.set(self, "customization_kube_proxy", value)

    @property
    @pulumi.getter
    @_utilities.deprecated("""Use customization_apiserver instead""")
    def customizations(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['KubeCustomizationArgs']]]]:
        """
        **Deprecated** (Optional) Use `customization_apiserver` and `customization_kube_proxy` instead. Kubernetes cluster customization
        """
        return pulumi.get(self, "customizations")

    @customizations.setter
    def customizations(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['KubeCustomizationArgs']]]]):
        pulumi.set(self, "customizations", value)

    @property
    @pulumi.getter(name="kubeProxyMode")
    def kube_proxy_mode(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Selected mode for kube-proxy. **Changing this value recreates the resource, including ETCD user data.** Defaults to `iptables`.
        """
        return pulumi.get(self, "kube_proxy_mode")

    @kube_proxy_mode.setter
    def kube_proxy_mode(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "kube_proxy_mode", value)

    @property
    @pulumi.getter(name="loadBalancersSubnetId")
    def load_balancers_subnet_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Subnet ID to use for Public Load Balancers, this subnet must belong to  `private_network_id`. Defaults to the same subnet as the nodes (see `nodes_subnet_id`). Requires `private_network_id` to be defined. See more network requirements in the [documentation](https://help.ovhcloud.com/csm/fr-public-cloud-kubernetes-expose-applications-using-load-balancer?id=kb_article_view&sysparm_article=KB0062873) for more information.
        """
        return pulumi.get(self, "load_balancers_subnet_id")

    @load_balancers_subnet_id.setter
    def load_balancers_subnet_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "load_balancers_subnet_id", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the kubernetes cluster.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="nodesSubnetId")
    def nodes_subnet_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Subnet ID to use for nodes, this subnet must belong to `private_network_id`. Default uses the first subnet belonging to the private network with id `private_network_id`. This attribute requires `private_network_id` to be defined. **Cannot be updated, it can only be used at cluster creation or reset.**
        """
        return pulumi.get(self, "nodes_subnet_id")

    @nodes_subnet_id.setter
    def nodes_subnet_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "nodes_subnet_id", value)

    @property
    @pulumi.getter(name="privateNetworkConfiguration")
    def private_network_configuration(self) -> Optional[pulumi.Input['KubePrivateNetworkConfigurationArgs']]:
        """
        The private network configuration. If this is set then the 2 parameters below shall be defined.
        """
        return pulumi.get(self, "private_network_configuration")

    @private_network_configuration.setter
    def private_network_configuration(self, value: Optional[pulumi.Input['KubePrivateNetworkConfigurationArgs']]):
        pulumi.set(self, "private_network_configuration", value)

    @property
    @pulumi.getter(name="privateNetworkId")
    def private_network_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Private network ID to use. **Changing this value recreates the resource, including ETCD user data.** Defaults - not use private network.

        > **WARNING** Updating the private network ID resets the cluster so that all user data is deleted.
        """
        return pulumi.get(self, "private_network_id")

    @private_network_id.setter
    def private_network_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "private_network_id", value)

    @property
    @pulumi.getter(name="updatePolicy")
    def update_policy(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Cluster update policy. Choose between [ALWAYS_UPDATE, MINIMAL_DOWNTIME, NEVER_UPDATE].
        """
        return pulumi.get(self, "update_policy")

    @update_policy.setter
    def update_policy(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "update_policy", value)

    @property
    @pulumi.getter
    def version(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        kubernetes version to use. Changing this value updates the resource. Defaults to the latest available.
        """
        return pulumi.get(self, "version")

    @version.setter
    def version(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "version", value)


@pulumi.input_type
class _KubeState:
    def __init__(__self__, *,
                 control_plane_is_up_to_date: Optional[pulumi.Input[builtins.bool]] = None,
                 customization_apiservers: Optional[pulumi.Input[Sequence[pulumi.Input['KubeCustomizationApiserverArgs']]]] = None,
                 customization_kube_proxy: Optional[pulumi.Input['KubeCustomizationKubeProxyArgs']] = None,
                 customizations: Optional[pulumi.Input[Sequence[pulumi.Input['KubeCustomizationArgs']]]] = None,
                 is_up_to_date: Optional[pulumi.Input[builtins.bool]] = None,
                 kube_proxy_mode: Optional[pulumi.Input[builtins.str]] = None,
                 kubeconfig: Optional[pulumi.Input[builtins.str]] = None,
                 kubeconfig_attributes: Optional[pulumi.Input[Sequence[pulumi.Input['KubeKubeconfigAttributeArgs']]]] = None,
                 load_balancers_subnet_id: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 next_upgrade_versions: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 nodes_subnet_id: Optional[pulumi.Input[builtins.str]] = None,
                 nodes_url: Optional[pulumi.Input[builtins.str]] = None,
                 private_network_configuration: Optional[pulumi.Input['KubePrivateNetworkConfigurationArgs']] = None,
                 private_network_id: Optional[pulumi.Input[builtins.str]] = None,
                 region: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 update_policy: Optional[pulumi.Input[builtins.str]] = None,
                 url: Optional[pulumi.Input[builtins.str]] = None,
                 version: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Kube resources.
        :param pulumi.Input[builtins.bool] control_plane_is_up_to_date: True if control-plane is up-to-date.
        :param pulumi.Input[Sequence[pulumi.Input['KubeCustomizationApiserverArgs']]] customization_apiservers: Kubernetes API server customization
        :param pulumi.Input['KubeCustomizationKubeProxyArgs'] customization_kube_proxy: Kubernetes kube-proxy customization
        :param pulumi.Input[Sequence[pulumi.Input['KubeCustomizationArgs']]] customizations: **Deprecated** (Optional) Use `customization_apiserver` and `customization_kube_proxy` instead. Kubernetes cluster customization
        :param pulumi.Input[builtins.bool] is_up_to_date: True if all nodes and control-plane are up-to-date.
        :param pulumi.Input[builtins.str] kube_proxy_mode: Selected mode for kube-proxy. **Changing this value recreates the resource, including ETCD user data.** Defaults to `iptables`.
        :param pulumi.Input[builtins.str] kubeconfig: The kubeconfig file. Use this file to connect to your kubernetes cluster.
        :param pulumi.Input[Sequence[pulumi.Input['KubeKubeconfigAttributeArgs']]] kubeconfig_attributes: The kubeconfig file attributes.
        :param pulumi.Input[builtins.str] load_balancers_subnet_id: Subnet ID to use for Public Load Balancers, this subnet must belong to  `private_network_id`. Defaults to the same subnet as the nodes (see `nodes_subnet_id`). Requires `private_network_id` to be defined. See more network requirements in the [documentation](https://help.ovhcloud.com/csm/fr-public-cloud-kubernetes-expose-applications-using-load-balancer?id=kb_article_view&sysparm_article=KB0062873) for more information.
        :param pulumi.Input[builtins.str] name: The name of the kubernetes cluster.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] next_upgrade_versions: Kubernetes versions available for upgrade.
        :param pulumi.Input[builtins.str] nodes_subnet_id: Subnet ID to use for nodes, this subnet must belong to `private_network_id`. Default uses the first subnet belonging to the private network with id `private_network_id`. This attribute requires `private_network_id` to be defined. **Cannot be updated, it can only be used at cluster creation or reset.**
        :param pulumi.Input[builtins.str] nodes_url: Cluster nodes URL.
        :param pulumi.Input['KubePrivateNetworkConfigurationArgs'] private_network_configuration: The private network configuration. If this is set then the 2 parameters below shall be defined.
        :param pulumi.Input[builtins.str] private_network_id: Private network ID to use. **Changing this value recreates the resource, including ETCD user data.** Defaults - not use private network.
               
               > **WARNING** Updating the private network ID resets the cluster so that all user data is deleted.
        :param pulumi.Input[builtins.str] region: a valid OVHcloud public cloud region ID in which the kubernetes cluster will be available. Ex.: "GRA1". Defaults to all public cloud regions. **Changing this value recreates the resource.**
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used. **Changing this value recreates the resource.**
        :param pulumi.Input[builtins.str] status: Cluster status. Should be normally set to 'READY'.
        :param pulumi.Input[builtins.str] update_policy: Cluster update policy. Choose between [ALWAYS_UPDATE, MINIMAL_DOWNTIME, NEVER_UPDATE].
        :param pulumi.Input[builtins.str] url: Management URL of your cluster.
        :param pulumi.Input[builtins.str] version: kubernetes version to use. Changing this value updates the resource. Defaults to the latest available.
        """
        if control_plane_is_up_to_date is not None:
            pulumi.set(__self__, "control_plane_is_up_to_date", control_plane_is_up_to_date)
        if customization_apiservers is not None:
            pulumi.set(__self__, "customization_apiservers", customization_apiservers)
        if customization_kube_proxy is not None:
            pulumi.set(__self__, "customization_kube_proxy", customization_kube_proxy)
        if customizations is not None:
            warnings.warn("""Use customization_apiserver instead""", DeprecationWarning)
            pulumi.log.warn("""customizations is deprecated: Use customization_apiserver instead""")
        if customizations is not None:
            pulumi.set(__self__, "customizations", customizations)
        if is_up_to_date is not None:
            pulumi.set(__self__, "is_up_to_date", is_up_to_date)
        if kube_proxy_mode is not None:
            pulumi.set(__self__, "kube_proxy_mode", kube_proxy_mode)
        if kubeconfig is not None:
            pulumi.set(__self__, "kubeconfig", kubeconfig)
        if kubeconfig_attributes is not None:
            pulumi.set(__self__, "kubeconfig_attributes", kubeconfig_attributes)
        if load_balancers_subnet_id is not None:
            pulumi.set(__self__, "load_balancers_subnet_id", load_balancers_subnet_id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if next_upgrade_versions is not None:
            pulumi.set(__self__, "next_upgrade_versions", next_upgrade_versions)
        if nodes_subnet_id is not None:
            pulumi.set(__self__, "nodes_subnet_id", nodes_subnet_id)
        if nodes_url is not None:
            pulumi.set(__self__, "nodes_url", nodes_url)
        if private_network_configuration is not None:
            pulumi.set(__self__, "private_network_configuration", private_network_configuration)
        if private_network_id is not None:
            pulumi.set(__self__, "private_network_id", private_network_id)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if update_policy is not None:
            pulumi.set(__self__, "update_policy", update_policy)
        if url is not None:
            pulumi.set(__self__, "url", url)
        if version is not None:
            pulumi.set(__self__, "version", version)

    @property
    @pulumi.getter(name="controlPlaneIsUpToDate")
    def control_plane_is_up_to_date(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        True if control-plane is up-to-date.
        """
        return pulumi.get(self, "control_plane_is_up_to_date")

    @control_plane_is_up_to_date.setter
    def control_plane_is_up_to_date(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "control_plane_is_up_to_date", value)

    @property
    @pulumi.getter(name="customizationApiservers")
    def customization_apiservers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['KubeCustomizationApiserverArgs']]]]:
        """
        Kubernetes API server customization
        """
        return pulumi.get(self, "customization_apiservers")

    @customization_apiservers.setter
    def customization_apiservers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['KubeCustomizationApiserverArgs']]]]):
        pulumi.set(self, "customization_apiservers", value)

    @property
    @pulumi.getter(name="customizationKubeProxy")
    def customization_kube_proxy(self) -> Optional[pulumi.Input['KubeCustomizationKubeProxyArgs']]:
        """
        Kubernetes kube-proxy customization
        """
        return pulumi.get(self, "customization_kube_proxy")

    @customization_kube_proxy.setter
    def customization_kube_proxy(self, value: Optional[pulumi.Input['KubeCustomizationKubeProxyArgs']]):
        pulumi.set(self, "customization_kube_proxy", value)

    @property
    @pulumi.getter
    @_utilities.deprecated("""Use customization_apiserver instead""")
    def customizations(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['KubeCustomizationArgs']]]]:
        """
        **Deprecated** (Optional) Use `customization_apiserver` and `customization_kube_proxy` instead. Kubernetes cluster customization
        """
        return pulumi.get(self, "customizations")

    @customizations.setter
    def customizations(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['KubeCustomizationArgs']]]]):
        pulumi.set(self, "customizations", value)

    @property
    @pulumi.getter(name="isUpToDate")
    def is_up_to_date(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        True if all nodes and control-plane are up-to-date.
        """
        return pulumi.get(self, "is_up_to_date")

    @is_up_to_date.setter
    def is_up_to_date(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "is_up_to_date", value)

    @property
    @pulumi.getter(name="kubeProxyMode")
    def kube_proxy_mode(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Selected mode for kube-proxy. **Changing this value recreates the resource, including ETCD user data.** Defaults to `iptables`.
        """
        return pulumi.get(self, "kube_proxy_mode")

    @kube_proxy_mode.setter
    def kube_proxy_mode(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "kube_proxy_mode", value)

    @property
    @pulumi.getter
    def kubeconfig(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The kubeconfig file. Use this file to connect to your kubernetes cluster.
        """
        return pulumi.get(self, "kubeconfig")

    @kubeconfig.setter
    def kubeconfig(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "kubeconfig", value)

    @property
    @pulumi.getter(name="kubeconfigAttributes")
    def kubeconfig_attributes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['KubeKubeconfigAttributeArgs']]]]:
        """
        The kubeconfig file attributes.
        """
        return pulumi.get(self, "kubeconfig_attributes")

    @kubeconfig_attributes.setter
    def kubeconfig_attributes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['KubeKubeconfigAttributeArgs']]]]):
        pulumi.set(self, "kubeconfig_attributes", value)

    @property
    @pulumi.getter(name="loadBalancersSubnetId")
    def load_balancers_subnet_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Subnet ID to use for Public Load Balancers, this subnet must belong to  `private_network_id`. Defaults to the same subnet as the nodes (see `nodes_subnet_id`). Requires `private_network_id` to be defined. See more network requirements in the [documentation](https://help.ovhcloud.com/csm/fr-public-cloud-kubernetes-expose-applications-using-load-balancer?id=kb_article_view&sysparm_article=KB0062873) for more information.
        """
        return pulumi.get(self, "load_balancers_subnet_id")

    @load_balancers_subnet_id.setter
    def load_balancers_subnet_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "load_balancers_subnet_id", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the kubernetes cluster.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="nextUpgradeVersions")
    def next_upgrade_versions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        Kubernetes versions available for upgrade.
        """
        return pulumi.get(self, "next_upgrade_versions")

    @next_upgrade_versions.setter
    def next_upgrade_versions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "next_upgrade_versions", value)

    @property
    @pulumi.getter(name="nodesSubnetId")
    def nodes_subnet_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Subnet ID to use for nodes, this subnet must belong to `private_network_id`. Default uses the first subnet belonging to the private network with id `private_network_id`. This attribute requires `private_network_id` to be defined. **Cannot be updated, it can only be used at cluster creation or reset.**
        """
        return pulumi.get(self, "nodes_subnet_id")

    @nodes_subnet_id.setter
    def nodes_subnet_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "nodes_subnet_id", value)

    @property
    @pulumi.getter(name="nodesUrl")
    def nodes_url(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Cluster nodes URL.
        """
        return pulumi.get(self, "nodes_url")

    @nodes_url.setter
    def nodes_url(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "nodes_url", value)

    @property
    @pulumi.getter(name="privateNetworkConfiguration")
    def private_network_configuration(self) -> Optional[pulumi.Input['KubePrivateNetworkConfigurationArgs']]:
        """
        The private network configuration. If this is set then the 2 parameters below shall be defined.
        """
        return pulumi.get(self, "private_network_configuration")

    @private_network_configuration.setter
    def private_network_configuration(self, value: Optional[pulumi.Input['KubePrivateNetworkConfigurationArgs']]):
        pulumi.set(self, "private_network_configuration", value)

    @property
    @pulumi.getter(name="privateNetworkId")
    def private_network_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Private network ID to use. **Changing this value recreates the resource, including ETCD user data.** Defaults - not use private network.

        > **WARNING** Updating the private network ID resets the cluster so that all user data is deleted.
        """
        return pulumi.get(self, "private_network_id")

    @private_network_id.setter
    def private_network_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "private_network_id", value)

    @property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        a valid OVHcloud public cloud region ID in which the kubernetes cluster will be available. Ex.: "GRA1". Defaults to all public cloud regions. **Changing this value recreates the resource.**
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "region", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used. **Changing this value recreates the resource.**
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Cluster status. Should be normally set to 'READY'.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="updatePolicy")
    def update_policy(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Cluster update policy. Choose between [ALWAYS_UPDATE, MINIMAL_DOWNTIME, NEVER_UPDATE].
        """
        return pulumi.get(self, "update_policy")

    @update_policy.setter
    def update_policy(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "update_policy", value)

    @property
    @pulumi.getter
    def url(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Management URL of your cluster.
        """
        return pulumi.get(self, "url")

    @url.setter
    def url(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "url", value)

    @property
    @pulumi.getter
    def version(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        kubernetes version to use. Changing this value updates the resource. Defaults to the latest available.
        """
        return pulumi.get(self, "version")

    @version.setter
    def version(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "version", value)


class Kube(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 customization_apiservers: Optional[pulumi.Input[Sequence[pulumi.Input[Union['KubeCustomizationApiserverArgs', 'KubeCustomizationApiserverArgsDict']]]]] = None,
                 customization_kube_proxy: Optional[pulumi.Input[Union['KubeCustomizationKubeProxyArgs', 'KubeCustomizationKubeProxyArgsDict']]] = None,
                 customizations: Optional[pulumi.Input[Sequence[pulumi.Input[Union['KubeCustomizationArgs', 'KubeCustomizationArgsDict']]]]] = None,
                 kube_proxy_mode: Optional[pulumi.Input[builtins.str]] = None,
                 load_balancers_subnet_id: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 nodes_subnet_id: Optional[pulumi.Input[builtins.str]] = None,
                 private_network_configuration: Optional[pulumi.Input[Union['KubePrivateNetworkConfigurationArgs', 'KubePrivateNetworkConfigurationArgsDict']]] = None,
                 private_network_id: Optional[pulumi.Input[builtins.str]] = None,
                 region: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 update_policy: Optional[pulumi.Input[builtins.str]] = None,
                 version: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        ## Import

        OVHcloud Managed Kubernetes Service clusters can be imported using the `service_name` and the `id` of the cluster, separated by "/" E.g.,

        bash

        ```sh
        $ pulumi import ovh:CloudProject/kube:Kube my_kube_cluster service_name/kube_id
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['KubeCustomizationApiserverArgs', 'KubeCustomizationApiserverArgsDict']]]] customization_apiservers: Kubernetes API server customization
        :param pulumi.Input[Union['KubeCustomizationKubeProxyArgs', 'KubeCustomizationKubeProxyArgsDict']] customization_kube_proxy: Kubernetes kube-proxy customization
        :param pulumi.Input[Sequence[pulumi.Input[Union['KubeCustomizationArgs', 'KubeCustomizationArgsDict']]]] customizations: **Deprecated** (Optional) Use `customization_apiserver` and `customization_kube_proxy` instead. Kubernetes cluster customization
        :param pulumi.Input[builtins.str] kube_proxy_mode: Selected mode for kube-proxy. **Changing this value recreates the resource, including ETCD user data.** Defaults to `iptables`.
        :param pulumi.Input[builtins.str] load_balancers_subnet_id: Subnet ID to use for Public Load Balancers, this subnet must belong to  `private_network_id`. Defaults to the same subnet as the nodes (see `nodes_subnet_id`). Requires `private_network_id` to be defined. See more network requirements in the [documentation](https://help.ovhcloud.com/csm/fr-public-cloud-kubernetes-expose-applications-using-load-balancer?id=kb_article_view&sysparm_article=KB0062873) for more information.
        :param pulumi.Input[builtins.str] name: The name of the kubernetes cluster.
        :param pulumi.Input[builtins.str] nodes_subnet_id: Subnet ID to use for nodes, this subnet must belong to `private_network_id`. Default uses the first subnet belonging to the private network with id `private_network_id`. This attribute requires `private_network_id` to be defined. **Cannot be updated, it can only be used at cluster creation or reset.**
        :param pulumi.Input[Union['KubePrivateNetworkConfigurationArgs', 'KubePrivateNetworkConfigurationArgsDict']] private_network_configuration: The private network configuration. If this is set then the 2 parameters below shall be defined.
        :param pulumi.Input[builtins.str] private_network_id: Private network ID to use. **Changing this value recreates the resource, including ETCD user data.** Defaults - not use private network.
               
               > **WARNING** Updating the private network ID resets the cluster so that all user data is deleted.
        :param pulumi.Input[builtins.str] region: a valid OVHcloud public cloud region ID in which the kubernetes cluster will be available. Ex.: "GRA1". Defaults to all public cloud regions. **Changing this value recreates the resource.**
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used. **Changing this value recreates the resource.**
        :param pulumi.Input[builtins.str] update_policy: Cluster update policy. Choose between [ALWAYS_UPDATE, MINIMAL_DOWNTIME, NEVER_UPDATE].
        :param pulumi.Input[builtins.str] version: kubernetes version to use. Changing this value updates the resource. Defaults to the latest available.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: KubeArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Import

        OVHcloud Managed Kubernetes Service clusters can be imported using the `service_name` and the `id` of the cluster, separated by "/" E.g.,

        bash

        ```sh
        $ pulumi import ovh:CloudProject/kube:Kube my_kube_cluster service_name/kube_id
        ```

        :param str resource_name: The name of the resource.
        :param KubeArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(KubeArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 customization_apiservers: Optional[pulumi.Input[Sequence[pulumi.Input[Union['KubeCustomizationApiserverArgs', 'KubeCustomizationApiserverArgsDict']]]]] = None,
                 customization_kube_proxy: Optional[pulumi.Input[Union['KubeCustomizationKubeProxyArgs', 'KubeCustomizationKubeProxyArgsDict']]] = None,
                 customizations: Optional[pulumi.Input[Sequence[pulumi.Input[Union['KubeCustomizationArgs', 'KubeCustomizationArgsDict']]]]] = None,
                 kube_proxy_mode: Optional[pulumi.Input[builtins.str]] = None,
                 load_balancers_subnet_id: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 nodes_subnet_id: Optional[pulumi.Input[builtins.str]] = None,
                 private_network_configuration: Optional[pulumi.Input[Union['KubePrivateNetworkConfigurationArgs', 'KubePrivateNetworkConfigurationArgsDict']]] = None,
                 private_network_id: Optional[pulumi.Input[builtins.str]] = None,
                 region: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 update_policy: Optional[pulumi.Input[builtins.str]] = None,
                 version: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = KubeArgs.__new__(KubeArgs)

            __props__.__dict__["customization_apiservers"] = customization_apiservers
            __props__.__dict__["customization_kube_proxy"] = customization_kube_proxy
            __props__.__dict__["customizations"] = customizations
            __props__.__dict__["kube_proxy_mode"] = kube_proxy_mode
            __props__.__dict__["load_balancers_subnet_id"] = load_balancers_subnet_id
            __props__.__dict__["name"] = name
            __props__.__dict__["nodes_subnet_id"] = nodes_subnet_id
            __props__.__dict__["private_network_configuration"] = private_network_configuration
            __props__.__dict__["private_network_id"] = private_network_id
            if region is None and not opts.urn:
                raise TypeError("Missing required property 'region'")
            __props__.__dict__["region"] = region
            if service_name is None and not opts.urn:
                raise TypeError("Missing required property 'service_name'")
            __props__.__dict__["service_name"] = service_name
            __props__.__dict__["update_policy"] = update_policy
            __props__.__dict__["version"] = version
            __props__.__dict__["control_plane_is_up_to_date"] = None
            __props__.__dict__["is_up_to_date"] = None
            __props__.__dict__["kubeconfig"] = None
            __props__.__dict__["kubeconfig_attributes"] = None
            __props__.__dict__["next_upgrade_versions"] = None
            __props__.__dict__["nodes_url"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["url"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["kubeconfig", "kubeconfigAttributes"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(Kube, __self__).__init__(
            'ovh:CloudProject/kube:Kube',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            control_plane_is_up_to_date: Optional[pulumi.Input[builtins.bool]] = None,
            customization_apiservers: Optional[pulumi.Input[Sequence[pulumi.Input[Union['KubeCustomizationApiserverArgs', 'KubeCustomizationApiserverArgsDict']]]]] = None,
            customization_kube_proxy: Optional[pulumi.Input[Union['KubeCustomizationKubeProxyArgs', 'KubeCustomizationKubeProxyArgsDict']]] = None,
            customizations: Optional[pulumi.Input[Sequence[pulumi.Input[Union['KubeCustomizationArgs', 'KubeCustomizationArgsDict']]]]] = None,
            is_up_to_date: Optional[pulumi.Input[builtins.bool]] = None,
            kube_proxy_mode: Optional[pulumi.Input[builtins.str]] = None,
            kubeconfig: Optional[pulumi.Input[builtins.str]] = None,
            kubeconfig_attributes: Optional[pulumi.Input[Sequence[pulumi.Input[Union['KubeKubeconfigAttributeArgs', 'KubeKubeconfigAttributeArgsDict']]]]] = None,
            load_balancers_subnet_id: Optional[pulumi.Input[builtins.str]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            next_upgrade_versions: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            nodes_subnet_id: Optional[pulumi.Input[builtins.str]] = None,
            nodes_url: Optional[pulumi.Input[builtins.str]] = None,
            private_network_configuration: Optional[pulumi.Input[Union['KubePrivateNetworkConfigurationArgs', 'KubePrivateNetworkConfigurationArgsDict']]] = None,
            private_network_id: Optional[pulumi.Input[builtins.str]] = None,
            region: Optional[pulumi.Input[builtins.str]] = None,
            service_name: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            update_policy: Optional[pulumi.Input[builtins.str]] = None,
            url: Optional[pulumi.Input[builtins.str]] = None,
            version: Optional[pulumi.Input[builtins.str]] = None) -> 'Kube':
        """
        Get an existing Kube resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.bool] control_plane_is_up_to_date: True if control-plane is up-to-date.
        :param pulumi.Input[Sequence[pulumi.Input[Union['KubeCustomizationApiserverArgs', 'KubeCustomizationApiserverArgsDict']]]] customization_apiservers: Kubernetes API server customization
        :param pulumi.Input[Union['KubeCustomizationKubeProxyArgs', 'KubeCustomizationKubeProxyArgsDict']] customization_kube_proxy: Kubernetes kube-proxy customization
        :param pulumi.Input[Sequence[pulumi.Input[Union['KubeCustomizationArgs', 'KubeCustomizationArgsDict']]]] customizations: **Deprecated** (Optional) Use `customization_apiserver` and `customization_kube_proxy` instead. Kubernetes cluster customization
        :param pulumi.Input[builtins.bool] is_up_to_date: True if all nodes and control-plane are up-to-date.
        :param pulumi.Input[builtins.str] kube_proxy_mode: Selected mode for kube-proxy. **Changing this value recreates the resource, including ETCD user data.** Defaults to `iptables`.
        :param pulumi.Input[builtins.str] kubeconfig: The kubeconfig file. Use this file to connect to your kubernetes cluster.
        :param pulumi.Input[Sequence[pulumi.Input[Union['KubeKubeconfigAttributeArgs', 'KubeKubeconfigAttributeArgsDict']]]] kubeconfig_attributes: The kubeconfig file attributes.
        :param pulumi.Input[builtins.str] load_balancers_subnet_id: Subnet ID to use for Public Load Balancers, this subnet must belong to  `private_network_id`. Defaults to the same subnet as the nodes (see `nodes_subnet_id`). Requires `private_network_id` to be defined. See more network requirements in the [documentation](https://help.ovhcloud.com/csm/fr-public-cloud-kubernetes-expose-applications-using-load-balancer?id=kb_article_view&sysparm_article=KB0062873) for more information.
        :param pulumi.Input[builtins.str] name: The name of the kubernetes cluster.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] next_upgrade_versions: Kubernetes versions available for upgrade.
        :param pulumi.Input[builtins.str] nodes_subnet_id: Subnet ID to use for nodes, this subnet must belong to `private_network_id`. Default uses the first subnet belonging to the private network with id `private_network_id`. This attribute requires `private_network_id` to be defined. **Cannot be updated, it can only be used at cluster creation or reset.**
        :param pulumi.Input[builtins.str] nodes_url: Cluster nodes URL.
        :param pulumi.Input[Union['KubePrivateNetworkConfigurationArgs', 'KubePrivateNetworkConfigurationArgsDict']] private_network_configuration: The private network configuration. If this is set then the 2 parameters below shall be defined.
        :param pulumi.Input[builtins.str] private_network_id: Private network ID to use. **Changing this value recreates the resource, including ETCD user data.** Defaults - not use private network.
               
               > **WARNING** Updating the private network ID resets the cluster so that all user data is deleted.
        :param pulumi.Input[builtins.str] region: a valid OVHcloud public cloud region ID in which the kubernetes cluster will be available. Ex.: "GRA1". Defaults to all public cloud regions. **Changing this value recreates the resource.**
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used. **Changing this value recreates the resource.**
        :param pulumi.Input[builtins.str] status: Cluster status. Should be normally set to 'READY'.
        :param pulumi.Input[builtins.str] update_policy: Cluster update policy. Choose between [ALWAYS_UPDATE, MINIMAL_DOWNTIME, NEVER_UPDATE].
        :param pulumi.Input[builtins.str] url: Management URL of your cluster.
        :param pulumi.Input[builtins.str] version: kubernetes version to use. Changing this value updates the resource. Defaults to the latest available.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _KubeState.__new__(_KubeState)

        __props__.__dict__["control_plane_is_up_to_date"] = control_plane_is_up_to_date
        __props__.__dict__["customization_apiservers"] = customization_apiservers
        __props__.__dict__["customization_kube_proxy"] = customization_kube_proxy
        __props__.__dict__["customizations"] = customizations
        __props__.__dict__["is_up_to_date"] = is_up_to_date
        __props__.__dict__["kube_proxy_mode"] = kube_proxy_mode
        __props__.__dict__["kubeconfig"] = kubeconfig
        __props__.__dict__["kubeconfig_attributes"] = kubeconfig_attributes
        __props__.__dict__["load_balancers_subnet_id"] = load_balancers_subnet_id
        __props__.__dict__["name"] = name
        __props__.__dict__["next_upgrade_versions"] = next_upgrade_versions
        __props__.__dict__["nodes_subnet_id"] = nodes_subnet_id
        __props__.__dict__["nodes_url"] = nodes_url
        __props__.__dict__["private_network_configuration"] = private_network_configuration
        __props__.__dict__["private_network_id"] = private_network_id
        __props__.__dict__["region"] = region
        __props__.__dict__["service_name"] = service_name
        __props__.__dict__["status"] = status
        __props__.__dict__["update_policy"] = update_policy
        __props__.__dict__["url"] = url
        __props__.__dict__["version"] = version
        return Kube(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="controlPlaneIsUpToDate")
    def control_plane_is_up_to_date(self) -> pulumi.Output[builtins.bool]:
        """
        True if control-plane is up-to-date.
        """
        return pulumi.get(self, "control_plane_is_up_to_date")

    @property
    @pulumi.getter(name="customizationApiservers")
    def customization_apiservers(self) -> pulumi.Output[Sequence['outputs.KubeCustomizationApiserver']]:
        """
        Kubernetes API server customization
        """
        return pulumi.get(self, "customization_apiservers")

    @property
    @pulumi.getter(name="customizationKubeProxy")
    def customization_kube_proxy(self) -> pulumi.Output[Optional['outputs.KubeCustomizationKubeProxy']]:
        """
        Kubernetes kube-proxy customization
        """
        return pulumi.get(self, "customization_kube_proxy")

    @property
    @pulumi.getter
    @_utilities.deprecated("""Use customization_apiserver instead""")
    def customizations(self) -> pulumi.Output[Sequence['outputs.KubeCustomization']]:
        """
        **Deprecated** (Optional) Use `customization_apiserver` and `customization_kube_proxy` instead. Kubernetes cluster customization
        """
        return pulumi.get(self, "customizations")

    @property
    @pulumi.getter(name="isUpToDate")
    def is_up_to_date(self) -> pulumi.Output[builtins.bool]:
        """
        True if all nodes and control-plane are up-to-date.
        """
        return pulumi.get(self, "is_up_to_date")

    @property
    @pulumi.getter(name="kubeProxyMode")
    def kube_proxy_mode(self) -> pulumi.Output[builtins.str]:
        """
        Selected mode for kube-proxy. **Changing this value recreates the resource, including ETCD user data.** Defaults to `iptables`.
        """
        return pulumi.get(self, "kube_proxy_mode")

    @property
    @pulumi.getter
    def kubeconfig(self) -> pulumi.Output[builtins.str]:
        """
        The kubeconfig file. Use this file to connect to your kubernetes cluster.
        """
        return pulumi.get(self, "kubeconfig")

    @property
    @pulumi.getter(name="kubeconfigAttributes")
    def kubeconfig_attributes(self) -> pulumi.Output[Sequence['outputs.KubeKubeconfigAttribute']]:
        """
        The kubeconfig file attributes.
        """
        return pulumi.get(self, "kubeconfig_attributes")

    @property
    @pulumi.getter(name="loadBalancersSubnetId")
    def load_balancers_subnet_id(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Subnet ID to use for Public Load Balancers, this subnet must belong to  `private_network_id`. Defaults to the same subnet as the nodes (see `nodes_subnet_id`). Requires `private_network_id` to be defined. See more network requirements in the [documentation](https://help.ovhcloud.com/csm/fr-public-cloud-kubernetes-expose-applications-using-load-balancer?id=kb_article_view&sysparm_article=KB0062873) for more information.
        """
        return pulumi.get(self, "load_balancers_subnet_id")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        The name of the kubernetes cluster.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="nextUpgradeVersions")
    def next_upgrade_versions(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        Kubernetes versions available for upgrade.
        """
        return pulumi.get(self, "next_upgrade_versions")

    @property
    @pulumi.getter(name="nodesSubnetId")
    def nodes_subnet_id(self) -> pulumi.Output[builtins.str]:
        """
        Subnet ID to use for nodes, this subnet must belong to `private_network_id`. Default uses the first subnet belonging to the private network with id `private_network_id`. This attribute requires `private_network_id` to be defined. **Cannot be updated, it can only be used at cluster creation or reset.**
        """
        return pulumi.get(self, "nodes_subnet_id")

    @property
    @pulumi.getter(name="nodesUrl")
    def nodes_url(self) -> pulumi.Output[builtins.str]:
        """
        Cluster nodes URL.
        """
        return pulumi.get(self, "nodes_url")

    @property
    @pulumi.getter(name="privateNetworkConfiguration")
    def private_network_configuration(self) -> pulumi.Output[Optional['outputs.KubePrivateNetworkConfiguration']]:
        """
        The private network configuration. If this is set then the 2 parameters below shall be defined.
        """
        return pulumi.get(self, "private_network_configuration")

    @property
    @pulumi.getter(name="privateNetworkId")
    def private_network_id(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Private network ID to use. **Changing this value recreates the resource, including ETCD user data.** Defaults - not use private network.

        > **WARNING** Updating the private network ID resets the cluster so that all user data is deleted.
        """
        return pulumi.get(self, "private_network_id")

    @property
    @pulumi.getter
    def region(self) -> pulumi.Output[builtins.str]:
        """
        a valid OVHcloud public cloud region ID in which the kubernetes cluster will be available. Ex.: "GRA1". Defaults to all public cloud regions. **Changing this value recreates the resource.**
        """
        return pulumi.get(self, "region")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Output[builtins.str]:
        """
        The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used. **Changing this value recreates the resource.**
        """
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        Cluster status. Should be normally set to 'READY'.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="updatePolicy")
    def update_policy(self) -> pulumi.Output[builtins.str]:
        """
        Cluster update policy. Choose between [ALWAYS_UPDATE, MINIMAL_DOWNTIME, NEVER_UPDATE].
        """
        return pulumi.get(self, "update_policy")

    @property
    @pulumi.getter
    def url(self) -> pulumi.Output[builtins.str]:
        """
        Management URL of your cluster.
        """
        return pulumi.get(self, "url")

    @property
    @pulumi.getter
    def version(self) -> pulumi.Output[builtins.str]:
        """
        kubernetes version to use. Changing this value updates the resource. Defaults to the latest available.
        """
        return pulumi.get(self, "version")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetVrackNetworkResult',
    'AwaitableGetVrackNetworkResult',
    'get_vrack_network',
    'get_vrack_network_output',
]

@pulumi.output_type
class GetVrackNetworkResult:
    """
    A collection of values returned by getVrackNetwork.
    """
    def __init__(__self__, display_name=None, id=None, nat_ip=None, service_name=None, subnet=None, vlan=None, vrack_network_id=None):
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if nat_ip and not isinstance(nat_ip, str):
            raise TypeError("Expected argument 'nat_ip' to be a str")
        pulumi.set(__self__, "nat_ip", nat_ip)
        if service_name and not isinstance(service_name, str):
            raise TypeError("Expected argument 'service_name' to be a str")
        pulumi.set(__self__, "service_name", service_name)
        if subnet and not isinstance(subnet, str):
            raise TypeError("Expected argument 'subnet' to be a str")
        pulumi.set(__self__, "subnet", subnet)
        if vlan and not isinstance(vlan, int):
            raise TypeError("Expected argument 'vlan' to be a int")
        pulumi.set(__self__, "vlan", vlan)
        if vrack_network_id and not isinstance(vrack_network_id, int):
            raise TypeError("Expected argument 'vrack_network_id' to be a int")
        pulumi.set(__self__, "vrack_network_id", vrack_network_id)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> builtins.str:
        """
        Human readable name for your vrack network
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="natIp")
    def nat_ip(self) -> builtins.str:
        """
        An IP block used as a pool of IPs by this Load Balancer to connect to the servers in this private network. The blck must be in the private network and reserved for the Load Balancer
        """
        return pulumi.get(self, "nat_ip")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> builtins.str:
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter
    def subnet(self) -> builtins.str:
        """
        IP block of the private network in the vRack
        """
        return pulumi.get(self, "subnet")

    @property
    @pulumi.getter
    def vlan(self) -> builtins.int:
        """
        VLAN of the private network in the vRack. 0 if the private network is not in a VLAN
        """
        return pulumi.get(self, "vlan")

    @property
    @pulumi.getter(name="vrackNetworkId")
    def vrack_network_id(self) -> builtins.int:
        return pulumi.get(self, "vrack_network_id")


class AwaitableGetVrackNetworkResult(GetVrackNetworkResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetVrackNetworkResult(
            display_name=self.display_name,
            id=self.id,
            nat_ip=self.nat_ip,
            service_name=self.service_name,
            subnet=self.subnet,
            vlan=self.vlan,
            vrack_network_id=self.vrack_network_id)


def get_vrack_network(service_name: Optional[builtins.str] = None,
                      vrack_network_id: Optional[builtins.int] = None,
                      opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetVrackNetworkResult:
    """
    Use this data source to get the details of Vrack network available for your IPLoadbalancer associated with your OVHcloud account.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    lb_network = ovh.IpLoadBalancing.get_vrack_network(service_name="XXXXXX",
        vrack_network_id="yyy")
    ```


    :param builtins.str service_name: The internal name of your IP load balancing
    :param builtins.int vrack_network_id: Internal Load Balancer identifier of the vRack private network
    """
    __args__ = dict()
    __args__['serviceName'] = service_name
    __args__['vrackNetworkId'] = vrack_network_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:IpLoadBalancing/getVrackNetwork:getVrackNetwork', __args__, opts=opts, typ=GetVrackNetworkResult).value

    return AwaitableGetVrackNetworkResult(
        display_name=pulumi.get(__ret__, 'display_name'),
        id=pulumi.get(__ret__, 'id'),
        nat_ip=pulumi.get(__ret__, 'nat_ip'),
        service_name=pulumi.get(__ret__, 'service_name'),
        subnet=pulumi.get(__ret__, 'subnet'),
        vlan=pulumi.get(__ret__, 'vlan'),
        vrack_network_id=pulumi.get(__ret__, 'vrack_network_id'))
def get_vrack_network_output(service_name: Optional[pulumi.Input[builtins.str]] = None,
                             vrack_network_id: Optional[pulumi.Input[builtins.int]] = None,
                             opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetVrackNetworkResult]:
    """
    Use this data source to get the details of Vrack network available for your IPLoadbalancer associated with your OVHcloud account.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    lb_network = ovh.IpLoadBalancing.get_vrack_network(service_name="XXXXXX",
        vrack_network_id="yyy")
    ```


    :param builtins.str service_name: The internal name of your IP load balancing
    :param builtins.int vrack_network_id: Internal Load Balancer identifier of the vRack private network
    """
    __args__ = dict()
    __args__['serviceName'] = service_name
    __args__['vrackNetworkId'] = vrack_network_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:IpLoadBalancing/getVrackNetwork:getVrackNetwork', __args__, opts=opts, typ=GetVrackNetworkResult)
    return __ret__.apply(lambda __response__: GetVrackNetworkResult(
        display_name=pulumi.get(__response__, 'display_name'),
        id=pulumi.get(__response__, 'id'),
        nat_ip=pulumi.get(__response__, 'nat_ip'),
        service_name=pulumi.get(__response__, 'service_name'),
        subnet=pulumi.get(__response__, 'subnet'),
        vlan=pulumi.get(__response__, 'vlan'),
        vrack_network_id=pulumi.get(__response__, 'vrack_network_id')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['RegionLoadBalancerLogSubscriptionArgs', 'RegionLoadBalancerLogSubscription']

@pulumi.input_type
class RegionLoadBalancerLogSubscriptionArgs:
    def __init__(__self__, *,
                 kind: pulumi.Input[builtins.str],
                 loadbalancer_id: pulumi.Input[builtins.str],
                 region_name: pulumi.Input[builtins.str],
                 service_name: pulumi.Input[builtins.str],
                 stream_id: pulumi.Input[builtins.str]):
        """
        The set of arguments for constructing a RegionLoadBalancerLogSubscription resource.
        :param pulumi.Input[builtins.str] kind: haproxy **Changing this value recreates the resource.**
        :param pulumi.Input[builtins.str] loadbalancer_id: Loadbalancer id to get the logs **Changing this value recreates the resource.**
        :param pulumi.Input[builtins.str] region_name: A valid OVHcloud public cloud region name in which the loadbalancer will be available. Ex.: "GRA11". **Changing this value recreates the resource.**
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used. **Changing this value recreates the resource.**
        :param pulumi.Input[builtins.str] stream_id: Data stream id to use for the subscription **Changing this value recreates the resource.**
        """
        pulumi.set(__self__, "kind", kind)
        pulumi.set(__self__, "loadbalancer_id", loadbalancer_id)
        pulumi.set(__self__, "region_name", region_name)
        pulumi.set(__self__, "service_name", service_name)
        pulumi.set(__self__, "stream_id", stream_id)

    @property
    @pulumi.getter
    def kind(self) -> pulumi.Input[builtins.str]:
        """
        haproxy **Changing this value recreates the resource.**
        """
        return pulumi.get(self, "kind")

    @kind.setter
    def kind(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "kind", value)

    @property
    @pulumi.getter(name="loadbalancerId")
    def loadbalancer_id(self) -> pulumi.Input[builtins.str]:
        """
        Loadbalancer id to get the logs **Changing this value recreates the resource.**
        """
        return pulumi.get(self, "loadbalancer_id")

    @loadbalancer_id.setter
    def loadbalancer_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "loadbalancer_id", value)

    @property
    @pulumi.getter(name="regionName")
    def region_name(self) -> pulumi.Input[builtins.str]:
        """
        A valid OVHcloud public cloud region name in which the loadbalancer will be available. Ex.: "GRA11". **Changing this value recreates the resource.**
        """
        return pulumi.get(self, "region_name")

    @region_name.setter
    def region_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "region_name", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Input[builtins.str]:
        """
        The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used. **Changing this value recreates the resource.**
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter(name="streamId")
    def stream_id(self) -> pulumi.Input[builtins.str]:
        """
        Data stream id to use for the subscription **Changing this value recreates the resource.**
        """
        return pulumi.get(self, "stream_id")

    @stream_id.setter
    def stream_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "stream_id", value)


@pulumi.input_type
class _RegionLoadBalancerLogSubscriptionState:
    def __init__(__self__, *,
                 created_at: Optional[pulumi.Input[builtins.str]] = None,
                 kind: Optional[pulumi.Input[builtins.str]] = None,
                 ldp_service_name: Optional[pulumi.Input[builtins.str]] = None,
                 loadbalancer_id: Optional[pulumi.Input[builtins.str]] = None,
                 operation_id: Optional[pulumi.Input[builtins.str]] = None,
                 region_name: Optional[pulumi.Input[builtins.str]] = None,
                 resource_name: Optional[pulumi.Input[builtins.str]] = None,
                 resource_type: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 stream_id: Optional[pulumi.Input[builtins.str]] = None,
                 subscription_id: Optional[pulumi.Input[builtins.str]] = None,
                 updated_at: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering RegionLoadBalancerLogSubscription resources.
        :param pulumi.Input[builtins.str] created_at: The date of the subscription creation
        :param pulumi.Input[builtins.str] kind: haproxy **Changing this value recreates the resource.**
        :param pulumi.Input[builtins.str] ldp_service_name: LDP service name
        :param pulumi.Input[builtins.str] loadbalancer_id: Loadbalancer id to get the logs **Changing this value recreates the resource.**
        :param pulumi.Input[builtins.str] operation_id: The operation ID
        :param pulumi.Input[builtins.str] region_name: A valid OVHcloud public cloud region name in which the loadbalancer will be available. Ex.: "GRA11". **Changing this value recreates the resource.**
        :param pulumi.Input[builtins.str] resource_name: The resource name
        :param pulumi.Input[builtins.str] resource_type: The resource type
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used. **Changing this value recreates the resource.**
        :param pulumi.Input[builtins.str] stream_id: Data stream id to use for the subscription **Changing this value recreates the resource.**
        :param pulumi.Input[builtins.str] subscription_id: The subscription id
        :param pulumi.Input[builtins.str] updated_at: The last update of the subscription
        """
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if kind is not None:
            pulumi.set(__self__, "kind", kind)
        if ldp_service_name is not None:
            pulumi.set(__self__, "ldp_service_name", ldp_service_name)
        if loadbalancer_id is not None:
            pulumi.set(__self__, "loadbalancer_id", loadbalancer_id)
        if operation_id is not None:
            pulumi.set(__self__, "operation_id", operation_id)
        if region_name is not None:
            pulumi.set(__self__, "region_name", region_name)
        if resource_name is not None:
            pulumi.set(__self__, "resource_name", resource_name)
        if resource_type is not None:
            pulumi.set(__self__, "resource_type", resource_type)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)
        if stream_id is not None:
            pulumi.set(__self__, "stream_id", stream_id)
        if subscription_id is not None:
            pulumi.set(__self__, "subscription_id", subscription_id)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The date of the subscription creation
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_at", value)

    @property
    @pulumi.getter
    def kind(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        haproxy **Changing this value recreates the resource.**
        """
        return pulumi.get(self, "kind")

    @kind.setter
    def kind(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "kind", value)

    @property
    @pulumi.getter(name="ldpServiceName")
    def ldp_service_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        LDP service name
        """
        return pulumi.get(self, "ldp_service_name")

    @ldp_service_name.setter
    def ldp_service_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ldp_service_name", value)

    @property
    @pulumi.getter(name="loadbalancerId")
    def loadbalancer_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Loadbalancer id to get the logs **Changing this value recreates the resource.**
        """
        return pulumi.get(self, "loadbalancer_id")

    @loadbalancer_id.setter
    def loadbalancer_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "loadbalancer_id", value)

    @property
    @pulumi.getter(name="operationId")
    def operation_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The operation ID
        """
        return pulumi.get(self, "operation_id")

    @operation_id.setter
    def operation_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "operation_id", value)

    @property
    @pulumi.getter(name="regionName")
    def region_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        A valid OVHcloud public cloud region name in which the loadbalancer will be available. Ex.: "GRA11". **Changing this value recreates the resource.**
        """
        return pulumi.get(self, "region_name")

    @region_name.setter
    def region_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "region_name", value)

    @property
    @pulumi.getter(name="resourceName")
    def resource_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The resource name
        """
        return pulumi.get(self, "resource_name")

    @resource_name.setter
    def resource_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "resource_name", value)

    @property
    @pulumi.getter(name="resourceType")
    def resource_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The resource type
        """
        return pulumi.get(self, "resource_type")

    @resource_type.setter
    def resource_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "resource_type", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used. **Changing this value recreates the resource.**
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter(name="streamId")
    def stream_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Data stream id to use for the subscription **Changing this value recreates the resource.**
        """
        return pulumi.get(self, "stream_id")

    @stream_id.setter
    def stream_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "stream_id", value)

    @property
    @pulumi.getter(name="subscriptionId")
    def subscription_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The subscription id
        """
        return pulumi.get(self, "subscription_id")

    @subscription_id.setter
    def subscription_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "subscription_id", value)

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The last update of the subscription
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "updated_at", value)


class RegionLoadBalancerLogSubscription(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 kind: Optional[pulumi.Input[builtins.str]] = None,
                 loadbalancer_id: Optional[pulumi.Input[builtins.str]] = None,
                 region_name: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 stream_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Subscribe to a Managed Loadbalance Logs Service in a public cloud project.

        ## Example Usage

        Create a subscription

        ```python
        import pulumi
        import pulumi_ovh as ovh

        subscription = ovh.cloud_project.RegionLoadBalancerLogSubscription("subscription",
            service_name="xxxxxxxxxxxxxxxxxxxxxxxxxxxxxx",
            region_name="yyyy",
            loadbalancer_id="aaaaaaaa-bbbb-cccc-dddd-eeeeeeeeeeee",
            kind="haproxy",
            stream_id="ffffffff-gggg-hhhh-iiii-jjjjjjjjjjjj")
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] kind: haproxy **Changing this value recreates the resource.**
        :param pulumi.Input[builtins.str] loadbalancer_id: Loadbalancer id to get the logs **Changing this value recreates the resource.**
        :param pulumi.Input[builtins.str] region_name: A valid OVHcloud public cloud region name in which the loadbalancer will be available. Ex.: "GRA11". **Changing this value recreates the resource.**
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used. **Changing this value recreates the resource.**
        :param pulumi.Input[builtins.str] stream_id: Data stream id to use for the subscription **Changing this value recreates the resource.**
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: RegionLoadBalancerLogSubscriptionArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Subscribe to a Managed Loadbalance Logs Service in a public cloud project.

        ## Example Usage

        Create a subscription

        ```python
        import pulumi
        import pulumi_ovh as ovh

        subscription = ovh.cloud_project.RegionLoadBalancerLogSubscription("subscription",
            service_name="xxxxxxxxxxxxxxxxxxxxxxxxxxxxxx",
            region_name="yyyy",
            loadbalancer_id="aaaaaaaa-bbbb-cccc-dddd-eeeeeeeeeeee",
            kind="haproxy",
            stream_id="ffffffff-gggg-hhhh-iiii-jjjjjjjjjjjj")
        ```

        :param str resource_name: The name of the resource.
        :param RegionLoadBalancerLogSubscriptionArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RegionLoadBalancerLogSubscriptionArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 kind: Optional[pulumi.Input[builtins.str]] = None,
                 loadbalancer_id: Optional[pulumi.Input[builtins.str]] = None,
                 region_name: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 stream_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RegionLoadBalancerLogSubscriptionArgs.__new__(RegionLoadBalancerLogSubscriptionArgs)

            if kind is None and not opts.urn:
                raise TypeError("Missing required property 'kind'")
            __props__.__dict__["kind"] = kind
            if loadbalancer_id is None and not opts.urn:
                raise TypeError("Missing required property 'loadbalancer_id'")
            __props__.__dict__["loadbalancer_id"] = loadbalancer_id
            if region_name is None and not opts.urn:
                raise TypeError("Missing required property 'region_name'")
            __props__.__dict__["region_name"] = region_name
            if service_name is None and not opts.urn:
                raise TypeError("Missing required property 'service_name'")
            __props__.__dict__["service_name"] = service_name
            if stream_id is None and not opts.urn:
                raise TypeError("Missing required property 'stream_id'")
            __props__.__dict__["stream_id"] = stream_id
            __props__.__dict__["created_at"] = None
            __props__.__dict__["ldp_service_name"] = None
            __props__.__dict__["operation_id"] = None
            __props__.__dict__["resource_name"] = None
            __props__.__dict__["resource_type"] = None
            __props__.__dict__["subscription_id"] = None
            __props__.__dict__["updated_at"] = None
        super(RegionLoadBalancerLogSubscription, __self__).__init__(
            'ovh:CloudProject/regionLoadBalancerLogSubscription:RegionLoadBalancerLogSubscription',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            created_at: Optional[pulumi.Input[builtins.str]] = None,
            kind: Optional[pulumi.Input[builtins.str]] = None,
            ldp_service_name: Optional[pulumi.Input[builtins.str]] = None,
            loadbalancer_id: Optional[pulumi.Input[builtins.str]] = None,
            operation_id: Optional[pulumi.Input[builtins.str]] = None,
            region_name: Optional[pulumi.Input[builtins.str]] = None,
            resource_name_: Optional[pulumi.Input[builtins.str]] = None,
            resource_type: Optional[pulumi.Input[builtins.str]] = None,
            service_name: Optional[pulumi.Input[builtins.str]] = None,
            stream_id: Optional[pulumi.Input[builtins.str]] = None,
            subscription_id: Optional[pulumi.Input[builtins.str]] = None,
            updated_at: Optional[pulumi.Input[builtins.str]] = None) -> 'RegionLoadBalancerLogSubscription':
        """
        Get an existing RegionLoadBalancerLogSubscription resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] created_at: The date of the subscription creation
        :param pulumi.Input[builtins.str] kind: haproxy **Changing this value recreates the resource.**
        :param pulumi.Input[builtins.str] ldp_service_name: LDP service name
        :param pulumi.Input[builtins.str] loadbalancer_id: Loadbalancer id to get the logs **Changing this value recreates the resource.**
        :param pulumi.Input[builtins.str] operation_id: The operation ID
        :param pulumi.Input[builtins.str] region_name: A valid OVHcloud public cloud region name in which the loadbalancer will be available. Ex.: "GRA11". **Changing this value recreates the resource.**
        :param pulumi.Input[builtins.str] resource_name_: The resource name
        :param pulumi.Input[builtins.str] resource_type: The resource type
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used. **Changing this value recreates the resource.**
        :param pulumi.Input[builtins.str] stream_id: Data stream id to use for the subscription **Changing this value recreates the resource.**
        :param pulumi.Input[builtins.str] subscription_id: The subscription id
        :param pulumi.Input[builtins.str] updated_at: The last update of the subscription
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RegionLoadBalancerLogSubscriptionState.__new__(_RegionLoadBalancerLogSubscriptionState)

        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["kind"] = kind
        __props__.__dict__["ldp_service_name"] = ldp_service_name
        __props__.__dict__["loadbalancer_id"] = loadbalancer_id
        __props__.__dict__["operation_id"] = operation_id
        __props__.__dict__["region_name"] = region_name
        __props__.__dict__["resource_name"] = resource_name_
        __props__.__dict__["resource_type"] = resource_type
        __props__.__dict__["service_name"] = service_name
        __props__.__dict__["stream_id"] = stream_id
        __props__.__dict__["subscription_id"] = subscription_id
        __props__.__dict__["updated_at"] = updated_at
        return RegionLoadBalancerLogSubscription(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[builtins.str]:
        """
        The date of the subscription creation
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter
    def kind(self) -> pulumi.Output[builtins.str]:
        """
        haproxy **Changing this value recreates the resource.**
        """
        return pulumi.get(self, "kind")

    @property
    @pulumi.getter(name="ldpServiceName")
    def ldp_service_name(self) -> pulumi.Output[builtins.str]:
        """
        LDP service name
        """
        return pulumi.get(self, "ldp_service_name")

    @property
    @pulumi.getter(name="loadbalancerId")
    def loadbalancer_id(self) -> pulumi.Output[builtins.str]:
        """
        Loadbalancer id to get the logs **Changing this value recreates the resource.**
        """
        return pulumi.get(self, "loadbalancer_id")

    @property
    @pulumi.getter(name="operationId")
    def operation_id(self) -> pulumi.Output[builtins.str]:
        """
        The operation ID
        """
        return pulumi.get(self, "operation_id")

    @property
    @pulumi.getter(name="regionName")
    def region_name(self) -> pulumi.Output[builtins.str]:
        """
        A valid OVHcloud public cloud region name in which the loadbalancer will be available. Ex.: "GRA11". **Changing this value recreates the resource.**
        """
        return pulumi.get(self, "region_name")

    @property
    @pulumi.getter(name="resourceName")
    def resource_name(self) -> pulumi.Output[builtins.str]:
        """
        The resource name
        """
        return pulumi.get(self, "resource_name")

    @property
    @pulumi.getter(name="resourceType")
    def resource_type(self) -> pulumi.Output[builtins.str]:
        """
        The resource type
        """
        return pulumi.get(self, "resource_type")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Output[builtins.str]:
        """
        The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used. **Changing this value recreates the resource.**
        """
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter(name="streamId")
    def stream_id(self) -> pulumi.Output[builtins.str]:
        """
        Data stream id to use for the subscription **Changing this value recreates the resource.**
        """
        return pulumi.get(self, "stream_id")

    @property
    @pulumi.getter(name="subscriptionId")
    def subscription_id(self) -> pulumi.Output[builtins.str]:
        """
        The subscription id
        """
        return pulumi.get(self, "subscription_id")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[builtins.str]:
        """
        The last update of the subscription
        """
        return pulumi.get(self, "updated_at")

